#!/usr/bin/env python

##############################################################################
##
## Copyright (C) 2021 Narda Safety Test Solutions GmbH.
## Contact: http://www.narda-sts.de
##
## Redistribution and use in source and binary forms,
## with or without modification, are permitted provided that the following
## conditions are met:
##
## 1.) Redistributions of source code must retain the above copyright notice,
## this list of conditions and the following disclaimer.
##
## 2.) Redistributions in binary form must reproduce the above copyright
## notice, this list of conditions and the following disclaimer in the
## documentation and/or other materials provided with the distribution.
##
## 3.) Neither the name of the copyright holder nor the names of its
## contributors may be used to endorse or promote products derived from this
## software without specific prior written permission.
##
## 4.) EXPORT CONTROL
## The Software, including technical data /cryptographic software,
## may be subject to, German, European Union and U.S. export controls and
## may be subject to import or export controls in other countries.
## The Licensee agrees to strictly comply with all applicable import and
## export regulations. He specifically agrees, that he must not disclose or
## otherwise export or re-export the Licensed Software or any part thereof
## delivered under this end user license agreement (EULA) to any country
## (including a national or resident of such country) without a valid export
## or import license. Please be aware that the Software may contain
## US-Content, therefor the Licensee represent and warrant that he is not a
## citizen of, or otherwise located within, an embargoed nation (including
## without limitation Iran, Syria, Sudan, Cuba, North Korea) and that he is
## not otherwise prohibited under the Export Laws from receiving the Software.
## All rights to Use the Software are granted on condition that such rights
## are forfeited if the Licensee fails to comply with
## the terms of this Agreement.
##
## 5.) SEVERABILITY
## Should any provision of this Agreement be or become invalid, ineffective
## or unenforceable, the remaining provisions of this Agreement shall be
## valid. The parties agree to replace the invalid, ineffective or
## unenforceable provision by a valid, effective and enforceable provision
## which best meets the commercial intention of the parties.
## The same shall apply in case of omissions.
##
## 6.) APPLICABLE LAW AND PLACE OF JURISTICATION
## This Agreement shall be constituted under the law of Germany.
## The United Nations Convention on the International Sale of Goods
## shall not apply to this Agreement. The Place of Jurisdiction for any
## dispute between the Parties shall be Tübingen (Germany).
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
## TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
## PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL Narda Safety Test Solutions GmbH
## BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
## CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
## SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
## INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
## CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
## ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.
##
##############################################################################



from pathlib import Path
import wx
from nardascripting.base.usrscriptbase import *
from nardascripting.base.signalsharkdev import *
import nardascripting.base.toolbox as tb


class MyUserScript(UsrScriptBase):
    """User script class"""

    def __init__(self, main_gui, dev=SignalSharkDev()):
        """Initialization. Please leave this line unchanged"""
        super().__init__(main_gui, dev, __file__)

        # Script settings.
        # -------------------------------------------------------------------------------
        # Please adapt the following lines of code according to your script.
        self._tab_name = 'Templates'
        self._scr_title = 'Simple User Script'
        self._scr_description = 'Script with short-time program flow.'
        # self._icon_path = self.script_path.joinpath('NardaScriptLauncher_example01.png')
        self._list_prio = 0
        self._nsl_executed_behavior = NSL_Executed_Behaviors.SHOW_NSL

        # Add class variables if needed
        # -------------------------------------------------------------------------------
        # self.my_variable = None

    def _run_script(self, args):
        """
        Script main function
        This method is called when a user clicks on the corresponding script button.
        """
        # Add your code here:

        # Get some user input and configuration stuff
        # -------------------------------------------------------------------------------
        # Load config parameter
        last_atten = self.config.get('last_atten', 0)

        # Ask the user to enter a value
        atten = None
        dlg = wx.TextEntryDialog(self.frm_dlghelper, 'Enter attenuation in dB', 'Attenuation')
        dlg.SetValue(str(last_atten))
        if self.ShowDlgModalTop(dlg) == wx.ID_OK:
            atten = tb.try_str_to_value(dlg.GetValue(), float)
        dlg.Destroy()  # Please do not forget to destroy the created dialog if you do not need it anymore

        # Exit script if user pressed cancel or entered wrong value
        if atten is None:
            return

        # Store config parameter
        self.config['last_atten'] = atten

        # Connect to the device and do a SHORT communication sequence
        # -------------------------------------------------------------------------------
        # 'self.signalshark': Provides access to the SignalShark device
        if not self.signalshark.connect():
            self.MessageBoxModal('Cannot connect to the device!', 'Connection error',
                                 wx.OK | wx.ICON_ERROR)
            return

        # Clear SCPI error queue
        self.signalshark.scpi.check_error()

        # 'self.signalshark.scpi': wraps SCPI command
        self.signalshark.scpi.sense.set_attenuator(atten)
        device_atten = self.signalshark.scpi.sense.get_attenuator()

        # Check SCPI error queue and value
        if self.signalshark.scpi.check_no_error() and device_atten == atten:
            self.MessageBoxModal('Attenuation value set successfully.', 'Info',
                                 wx.OK | wx.ICON_INFORMATION)
        else:
            self.MessageBoxModal('The desired attenuation value could not be set.', 'Error',
                                 wx.OK | wx.ICON_ERROR)

        # Disconnect from the device
        # -------------------------------------------------------------------------------
        self.signalshark.disconnect()
